<ul>
    {level_0}
    <li class="{active_menu_item_class}">
        <a href="{href}">{name}</a>
        {remove_marker_start}
        <ul>
        {remove_marker_end}
            {level_1}
            <li>
                <a href="{href}">{name}</a>
                {remove_marker_start}
                <ul>
                {remove_marker_end}
                    {level_2}
                    <li>
                        <a href="{href}">{name}</a>
                    </li>
                    {/level_2}
                {remove_marker_start}
                </ul>
                {remove_marker_end}
            </li>
            {/level_1}
        {remove_marker_start}
        </ul>
        {remove_marker_end}
    </li>
    {/level_0}
</ul>