<?php 

$lang['module_name'] = 'Menu configuration';

$lang['new_item'] = 'menu item';

$lang['field_list'] = array(
    'translate_name' => 'Item name',
    'parent_id' => 'Parent',
    'href' => 'Page',
    'active_class' => 'Class of active element',
    'template' => 'Template',
    'view_order' => 'View order',
    'active' => 'Active',
    'name' => 'Name',
    'id_site_menu_type' => 'Menu'
);
$lang['active'] = 'Yes';
$lang['no_active'] = 'No';