<div class="breadcrumbs">
    {sub_items}
    <a href="{href}">{name}</a>
    <em>&#62;</em>
    {/sub_items}
    <?php if (!empty($current)) : ?>
        <span><?php echo $current ?></span>
    <?php endif; ?>
</div>