<?php

return[
    'project_modules' => [
        'pages' => [
            'site_menu_mod' => [
                'label'        => 'Меню сайта(site_menu)',
                'file'         => __DIR__ . '/../docs/site_menu.md',
                'position'     => 75,
                'acl_resource' => 'site_menu',
                'acl_action'   => 'edit_user_menu',
                'uri'          => 'site_menu/manager',
            ],
        ]
    ],
];
