<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Create bread crumbs
 *
 * @author Igor Ratsun
 */
class parser_breadcrumbs
{

    public function parse($menu_id = '', $force_last_item = false)
    {
        return Modules::run('site_menu/site_menu/breadcrumbs', $menu_id, $force_last_item);
    }

}
