<ul class="nav nav-tabs">
    {tabs}
    <li {class}><a href="/<?= $this->config->item('admin_page') ?>/mconfig/index/site_menu/manager/{id_site_menu_type}">{name}</a></li>
    {/tabs}
</ul>
<div class="tab-content">
    {content}
</div>